window.Gleam.initSearch([{"doc":"atomic_array","title":"atomic_array","content":"# atomic_array\n\nAtomic mutable int arrays for Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/atomic_array)](https://hex.pm/packages/atomic_array)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/atomic_array/)\n\n```sh\ngleam add atomic_array@1\n```\n```gleam\nimport atomic_array\n\npub fn main() {\n  let array = atomic_array.new_signed(size: 30)\n\n  // Mutate the array\n  let assert Ok(_) = atomic_array.add(array, 0, 5)\n  let assert Ok(_) = atomic_array.add(array, 0, 5)\n\n  // The array is mutated\n  array\n  |&gt; atomic_array.get(0)\n  |&gt; should.equal(Ok(10))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/atomic_array&gt;.\n","url":"index.html"},{"doc":"atomic_array","title":"AtomicArray","content":"pub type AtomicArray\n A mutable atomic array of 64bit ints, either signed or unsigned depending\n on whether it was created with the `new_unsigned` or `new_signed` function.\n\n\nSynonyms:\natomic_array.AtomicArray\natomic_array AtomicArray","url":"atomic_array.html#AtomicArray"},{"doc":"atomic_array","title":"CompareError","content":"pub type CompareError {\n  ComparisonOutOfBounds\n  ComparisonFailed(actual: Int)\n}\n\nComparisonOutOfBounds\n\n\nComparisonFailed(actual: Int)\n\n\nSynonyms:\natomic_array.CompareError\natomic_array CompareError","url":"atomic_array.html#CompareError"},{"doc":"atomic_array","title":"add","content":"pub fn add(\n  array: AtomicArray,\n  index: Int,\n  amount: Int,\n) -&gt; Result(Nil, Nil)\n Add an amount to an int at the given index in the array.\n\n Returns an error if the index is out of bounds.\n\n Will overflow or underflow if the resulting value does not fit in the int\n size for the array. \n\nSynonyms:\natomic_array.add\natomic_array add","url":"atomic_array.html#add"},{"doc":"atomic_array","title":"compare_exchange","content":"pub fn compare_exchange(\n  in array: AtomicArray,\n  at index: Int,\n  expect expected: Int,\n  replace_with value: Int,\n) -&gt; Result(Nil, CompareError)\n Replace an int in the array with a new one, providing that the int in the\n array has some expected value.\n\n Returns an error if the index is out of bounds.\n\nSynonyms:\natomic_array.compare_exchange\natomic_array compare_exchange","url":"atomic_array.html#compare_exchange"},{"doc":"atomic_array","title":"exchange","content":"pub fn exchange(\n  in array: AtomicArray,\n  at index: Int,\n  replace_with value: Int,\n) -&gt; Result(Int, Nil)\n Replace an int in the array with a new one.\n\n Returns an error if the index is out of bounds.\n\nSynonyms:\natomic_array.exchange\natomic_array exchange","url":"atomic_array.html#exchange"},{"doc":"atomic_array","title":"get","content":"pub fn get(array: AtomicArray, index: Int) -&gt; Result(Int, Nil)\n Read an int from the array.\n\n Returns an error if the index is out of bounds.\n\nSynonyms:\natomic_array.get\natomic_array get","url":"atomic_array.html#get"},{"doc":"atomic_array","title":"new_signed","content":"pub fn new_signed(size size: Int) -&gt; AtomicArray\n Create a new signed 64bit int array.\nSynonyms:\natomic_array.new_signed\natomic_array new_signed","url":"atomic_array.html#new_signed"},{"doc":"atomic_array","title":"new_unsigned","content":"pub fn new_unsigned(size size: Int) -&gt; AtomicArray\n Create a new unsigned 64bit int array.\nSynonyms:\natomic_array.new_unsigned\natomic_array new_unsigned","url":"atomic_array.html#new_unsigned"},{"doc":"atomic_array","title":"set","content":"pub fn set(\n  array: AtomicArray,\n  index: Int,\n  value: Int,\n) -&gt; Result(Nil, Nil)\n Set the int at the given index to a new value.\n\n Returns an error if the index is out of bounds.\n\n If the new value does not fit for the size of int that the array contains\n then it will overflow on JavaScript, but an error will be returned on\n Erlang. If you want to make a pull request to make this consistent then we\n will accept your changes!\n\nSynonyms:\natomic_array.set\natomic_array set","url":"atomic_array.html#set"},{"doc":"atomic_array","title":"size","content":"pub fn size(array: AtomicArray) -&gt; Int\n Get the number of ints in the array.\n\n Atomic arrays cannot be grown or shunk, they always have the same number of\n elements as they were created with.\n\nSynonyms:\natomic_array.size\natomic_array size","url":"atomic_array.html#size"},{"doc":"atomic_array","title":"to_list","content":"pub fn to_list(array: AtomicArray) -&gt; List(Int)\n Convert the array to a list of ints.\n\n Note that this operation is not atomic, so if another thread mutates the\n array while this function is running you may see inconsistent results.\n\nSynonyms:\natomic_array.to_list\natomic_array to_list","url":"atomic_array.html#to_list"},{"doc":"atomic_array","title":"atomic_array","content":" Atomic mutable arrays with these properties:\n\n\n - Atomics are 64 bit integers.\n - Atomics can be represented as either signed or unsigned.\n - Atomics wrap around at overflow and underflow operations.\n - All operations guarantee atomicity. No intermediate results can be seen.\n   The result of one mutation can only be the input to one following mutation.\n - All atomic operations are mutually ordered. If atomic B is updated after\n   atomic A, then that is how it will appear to any concurrent readers. No one\n   can read the new value of B and then read the old value of A.\n - Indexes into atomic arrays are zero-based. An atomic array of arity N\n   contains N atomics with index from 0 to N-1.\n\n Be aware that JavaScript numbers (and so Gleam `Int`s) cannot represent\n all 64bit ints, so the larger and smaller values that can be contained\n within array will lose precision when converted to a Gleam int with\n functions such as `get` and `to_list`.","url":"atomic_array.html"}]);